@@ -10,11 +10,11 @@ cli::tsv::util - The great new cli::tsv::util!
 
 =head1 VERSION
 
-Version 0.511
+Version 0.512
 
 =cut
 
-our $VERSION = '0.511';
+our $VERSION = '0.512';
 
 
 =head1 SYNOPSIS
@@ -22,12 +22,12 @@ our $VERSION = '0.511';
 The following 6 files (each with function explanation after ":" )
 will be installed by folloinwg INSTALLATION instruction.
 
-   1. csv2tsv  : Converting CSV format into TSV (Tab-Seprated Variable).
-   2. colsummary : A great table decipher by looking into each coloumns.
-   3. colgrep  : Extension of "grep" command searching on specified columns.
-   4. colsplit  : Splitting a TSV file into files of the each column.
-   5. colwidth   : Extracting `column width' informations.
-   6. latextable  : Useful when you need latex tables from Excel/SQL results.
+   1. colsummary : A great table decipher by looking into each coloumns.
+   2. colgrep  : Extension of "grep" command searching on specified columns.
+   3. colsplit  : Splitting a TSV file into files of the each column.
+   4. colwidth   : Extracting `column width' informations.
+   5. latextable  : Useful when you need latex tables from Excel/SQL results.
+   6. csv2tsv 
 
   The function detail can be shown by --help after each command but 
   as of 2018.03.25, most of them is written in Japanese. Sorry. 
